==> jc-1.4.0.tar.gz: soot/toolkits/scalar/StringGroupPair.h <==
// class soot.toolkits.scalar.StringGroupPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3bb60ff89904fbb5 soot_toolkits_scalar_StringGroupPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_StringGroupPair_H_
#define _JC_soot_toolkits_scalar_StringGroupPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$sub_refs	_jc_soot_toolkits_scalar_StringGroupPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs	_jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$refs	_jc_soot_toolkits_scalar_StringGroupPair$refs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$nonrefs	_jc_soot_toolkits_scalar_StringGroupPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$object	_jc_soot_toolkits_scalar_StringGroupPair$object;

typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vmethods	_jc_soot_toolkits_scalar_StringGroupPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vtable	_jc_soot_toolkits_scalar_StringGroupPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vtype	_jc_soot_toolkits_scalar_StringGroupPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_StringGroupPair$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_StringGroupPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_toolkits_scalar_StringGroupPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_StringGroupPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_StringGroupPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_StringGroupPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_StringGroupPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_StringGroupPair$vmethods	soot_toolkits_scalar_StringGroupPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_StringGroupPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_StringGroupPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_StringGroupPair$sub_refs {
	struct _jc_java_lang_String$object	*string;
	struct _jc_java_lang_Object$object	*group;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_StringGroupPair$refs {
    _jc_soot_toolkits_scalar_StringGroupPair$sub_refs	soot_toolkits_scalar_StringGroupPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_StringGroupPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs	soot_toolkits_scalar_StringGroupPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_StringGroupPair$object {
	_jc_soot_toolkits_scalar_StringGroupPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_StringGroupPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_StringGroupPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_StringGroupPair$vtype _jc_soot_toolkits_scalar_StringGroupPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_StringGroupPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_StringGroupPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_StringGroupPair_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/StringGroupPair.h <==
// class soot.toolkits.scalar.StringGroupPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3bb60ff89904fbb5 soot_toolkits_scalar_StringGroupPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_StringGroupPair_H_
#define _JC_soot_toolkits_scalar_StringGroupPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$sub_refs	_jc_soot_toolkits_scalar_StringGroupPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs	_jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$refs	_jc_soot_toolkits_scalar_StringGroupPair$refs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$nonrefs	_jc_soot_toolkits_scalar_StringGroupPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_StringGroupPair$object	_jc_soot_toolkits_scalar_StringGroupPair$object;

typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vmethods	_jc_soot_toolkits_scalar_StringGroupPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vtable	_jc_soot_toolkits_scalar_StringGroupPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_StringGroupPair$vtype	_jc_soot_toolkits_scalar_StringGroupPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_StringGroupPair$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_StringGroupPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_StringGroupPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_StringGroupPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_StringGroupPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_StringGroupPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_StringGroupPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_StringGroupPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_StringGroupPair$vmethods	soot_toolkits_scalar_StringGroupPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_StringGroupPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_StringGroupPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_StringGroupPair$sub_refs {
	struct _jc_java_lang_String$object	*string;
	struct _jc_java_lang_Object$object	*group;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_StringGroupPair$refs {
    _jc_soot_toolkits_scalar_StringGroupPair$sub_refs	soot_toolkits_scalar_StringGroupPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_StringGroupPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_StringGroupPair$sub_nonrefs	soot_toolkits_scalar_StringGroupPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_StringGroupPair$object {
	_jc_soot_toolkits_scalar_StringGroupPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_StringGroupPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_StringGroupPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_StringGroupPair$vtype _jc_soot_toolkits_scalar_StringGroupPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_StringGroupPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_StringGroupPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_StringGroupPair_H_ */
